@@ -3,6 +3,7 @@ import os
 import glob
 
 from mipdb.database import MonetDB, get_db_config
+from mipdb.dataset import Dataset
 from mipdb.reader import CSVFileReader, JsonFileReader
 from mipdb.usecases import AddDataModel, Cleanup
 from mipdb.usecases import AddPropertyToDataModel
@@ -98,9 +99,9 @@ def add_data_model(file, ip, port):
     db = MonetDB.from_config(dbconfig)
     data_model_metadata = reader.read()
     AddDataModel(db).execute(data_model_metadata)
-    print(
-        f"Data model {os.path.basename(os.path.normpath(file))} was successfully added."
-    )
+    code = data_model_metadata["code"]
+    version = data_model_metadata["version"]
+    print(f"Data model {code}:{version} was successfully added.")
 
 
 @entry.command()
@@ -122,7 +123,8 @@ def add_dataset(file, data_model, version, ip, port):
     dataset_data = reader.read()
     ValidateDataset(db).execute(dataset_data, data_model, version)
     AddDataset(db).execute(dataset_data, data_model, version)
-    print(f"Dataset {os.path.basename(os.path.normpath(file))} was successfully added.")
+    dataset = Dataset(dataset_data)
+    print(f"Dataset {dataset.name} was successfully added.")
 
 
 @entry.command()
