@@ -70,6 +70,14 @@ class Connection(ABC):
     def update_dataset_status(self, status, dataset_id):
         pass
 
+    @abstractmethod
+    def get_dataset(self, dataset_id, columns):
+        pass
+
+    @abstractmethod
+    def get_data_model(self, data_model_id, columns):
+        pass
+
     @abstractmethod
     def get_datasets(self, data_model_id, columns):
         pass
@@ -118,6 +126,10 @@ class Connection(ABC):
     def create_table(self, table):
         pass
 
+    @abstractmethod
+    def table_exists(self, table):
+        pass
+
     @abstractmethod
     def insert_values_to_table(self, values, table):
         pass
@@ -194,6 +206,14 @@ class DataBase(ABC):
     def get_schemas(self):
         pass
 
+    @abstractmethod
+    def get_dataset(self, dataset_id, columns):
+        pass
+
+    @abstractmethod
+    def get_data_model(self, data_model_id, columns):
+        pass
+
     @abstractmethod
     def get_datasets(self, data_model_id, columns):
         pass
@@ -210,6 +230,10 @@ class DataBase(ABC):
     def get_data_count_by_dataset(self, schema_fullname):
         pass
 
+    @abstractmethod
+    def table_exists(self, table):
+        pass
+
     @abstractmethod
     def create_table(self, table):
         pass
@@ -393,12 +417,38 @@ class DBExecutorMixin(ABC):
         )
         return list(res)
 
+    def get_dataset(self, dataset_id, columns):
+        columns_query = ", ".join(columns) if columns else "*"
+
+        dataset = self.execute(
+            f"""
+                SELECT {columns_query}
+                FROM {METADATA_SCHEMA}.datasets
+                WHERE dataset_id = {dataset_id}
+                LIMIT 1
+            """
+        ).fetchone()
+
+        return dataset
+
+    def get_data_model(self, data_model_id, columns):
+        columns_query = ", ".join(columns) if columns else "*"
+        data_model = self.execute(
+            f"""
+                SELECT {columns_query}
+                FROM {METADATA_SCHEMA}.data_models
+                WHERE data_model_id = {data_model_id}
+                LIMIT 1
+            """
+        ).fetchone()
+        return data_model
+
     def get_data_models(self, columns=None):
         columns_query = ", ".join(columns) if columns else "*"
         data_models = self.execute(
             f"""
             SELECT {columns_query}
-            FROM {METADATA_SCHEMA}.data_models as data_models
+            FROM {METADATA_SCHEMA}.data_models
             """
         )
 
@@ -417,6 +467,9 @@ class DBExecutorMixin(ABC):
         )
         return list(datasets)
 
+    def table_exists(self, table):
+        return table.exists(bind=self._executor)
+
     @handle_errors
     def create_table(self, table):
         table.create(bind=self._executor)
